# SBMLDiagrams
[![Coverage](https://codecov.io/gh/sunnyXu/SBMLDiagrams/branch/main/graph/badge.svg)](https://codecov.io/gh/sunnyXu/SBMLDiagrams)

## Introduction
SBMLDiagrams can visualize SBML to PNG/JPG/PDF files by visualizeSBML. On one hand, users can get 
all the information about Compartment, Node and Reaction from an SBML file to DataFrame by importSBML. On the other hand, it supports users to generate SBML files based on the information of DataFrame. Users can edit the DataFrame and update the information with or without editSBML so that can generate a new SBML file via exportSBML. This package supports SBML level 3, including layout and render. Namely, it does not only provide position and color information but also supports different shapes of nodes or alias nodes. If you use any part of this python package, please cite the Gihub website (https://github.com/SunnyXu/SBMLDiagrams).

## Installation

``pip install SBMLDiagrams``

## Documentation
Please see documentation at https://sunnyxu.github.io/SBMLDiagrams/ for details.


